@@ -1,5 +1,7 @@
 """
-Main interface for batch service literal definitions.
+Type annotations for batch service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_batch/literals.html)
 
 Usage::
 
